import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.get_summary_reports200_response import GetSummaryReports200Response
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.report_single_response import ReportSingleResponse
from smscx_client.model.reports_advanced_response import ReportsAdvancedResponse
from smscx_client.model.reports_campaign_response import ReportsCampaignResponse
from smscx_client.model.reports_campaigns_respone import ReportsCampaignsRespone


class ReportsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.export_advanced_report_to_csv_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/csv',
                'operation_id': 'export_advanced_report_to_csv',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'period',
                    'start_date',
                    'end_date',
                    'channel',
                    'source',
                    'delivery_report',
                    'country_iso',
                    'limit',
                ],
                'required': [
                    'period',
                    'start_date',
                    'end_date',
                ],
                'nullable': [
                ],
                'enum': [
                    'channel',
                    'source',
                    'delivery_report',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('channel',): {

                        "SMS": "sms",
                        "VIBER": "viber",
                        "WHATSAPP": "whatsapp",
                        "MULTICHANNEL": "multichannel"
                    },
                    ('source',): {

                        "API": "api",
                        "EXCEL": "excel",
                        "WEBAPP": "webapp",
                        "SMPP": "smpp",
                        "PLUGIN": "plugin",
                        "ALERTS": "alerts"
                    },
                    ('delivery_report',): {

                        "DELIVERED": "delivered",
                        "FAILED": "failed",
                        "SENT": "sent",
                        "ACCEPTED": "accepted",
                        "REJECTED": "rejected",
                        "SCHEDULED": "scheduled"
                    },
                },
                'api_types': {
                    'period':
                        (str,),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'channel':
                        (str,),
                    'source':
                        (str,),
                    'delivery_report':
                        (str,),
                    'country_iso':
                        (str,),
                    'limit':
                        (int,),
                },
                'attribute_map': {
                    'period': 'period',
                    'start_date': 'start_date',
                    'end_date': 'end_date',
                    'channel': 'channel',
                    'source': 'source',
                    'delivery_report': 'delivery_report',
                    'country_iso': 'country_iso',
                    'limit': 'limit',
                },
                'location_map': {
                    'period': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'channel': 'query',
                    'source': 'query',
                    'delivery_report': 'query',
                    'country_iso': 'query',
                    'limit': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/csv',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_advanced_report_to_xlsx_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/xlsx',
                'operation_id': 'export_advanced_report_to_xlsx',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'period',
                    'start_date',
                    'end_date',
                    'channel',
                    'source',
                    'delivery_report',
                    'country_iso',
                    'limit',
                ],
                'required': [
                    'period',
                    'start_date',
                    'end_date',
                ],
                'nullable': [
                ],
                'enum': [
                    'channel',
                    'source',
                    'delivery_report',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('channel',): {

                        "SMS": "sms",
                        "VIBER": "viber",
                        "WHATSAPP": "whatsapp",
                        "MULTICHANNEL": "multichannel"
                    },
                    ('source',): {

                        "API": "api",
                        "EXCEL": "excel",
                        "WEBAPP": "webapp",
                        "SMPP": "smpp",
                        "PLUGIN": "plugin",
                        "ALERTS": "alerts"
                    },
                    ('delivery_report',): {

                        "DELIVERED": "delivered",
                        "FAILED": "failed",
                        "SENT": "sent",
                        "ACCEPTED": "accepted",
                        "REJECTED": "rejected",
                        "SCHEDULED": "scheduled"
                    },
                },
                'api_types': {
                    'period':
                        (str,),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'channel':
                        (str,),
                    'source':
                        (str,),
                    'delivery_report':
                        (str,),
                    'country_iso':
                        (str,),
                    'limit':
                        (int,),
                },
                'attribute_map': {
                    'period': 'period',
                    'start_date': 'start_date',
                    'end_date': 'end_date',
                    'channel': 'channel',
                    'source': 'source',
                    'delivery_report': 'delivery_report',
                    'country_iso': 'country_iso',
                    'limit': 'limit',
                },
                'location_map': {
                    'period': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'channel': 'query',
                    'source': 'query',
                    'delivery_report': 'query',
                    'country_iso': 'query',
                    'limit': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_campaign_report_to_csv_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/campaigns/{campaignId}/csv',
                'operation_id': 'export_campaign_report_to_csv',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'campaign_id',
                ],
                'required': [
                    'campaign_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'campaign_id',
                ]
            },
            root_map={
                'validations': {
                    ('campaign_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'campaign_id':
                        (str,),
                },
                'attribute_map': {
                    'campaign_id': 'campaignId',
                },
                'location_map': {
                    'campaign_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/csv',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_campaign_report_to_xlsx_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/campaigns/{campaignId}/xlsx',
                'operation_id': 'export_campaign_report_to_xlsx',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'campaign_id',
                ],
                'required': [
                    'campaign_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'campaign_id',
                ]
            },
            root_map={
                'validations': {
                    ('campaign_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'campaign_id':
                        (str,),
                },
                'attribute_map': {
                    'campaign_id': 'campaignId',
                },
                'location_map': {
                    'campaign_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_advanced_report_endpoint = _Endpoint(
            settings={
                'response_type': (ReportsAdvancedResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports',
                'operation_id': 'get_advanced_report',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'period',
                    'start_date',
                    'end_date',
                    'channel',
                    'source',
                    'delivery_report',
                    'country_iso',
                    'short_response',
                    'limit',
                    'next',
                    'previous',
                ],
                'required': [
                    'period',
                    'start_date',
                    'end_date',
                ],
                'nullable': [
                ],
                'enum': [
                    'channel',
                    'source',
                    'delivery_report',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('channel',): {

                        "SMS": "sms",
                        "VIBER": "viber",
                        "WHATSAPP": "whatsapp",
                        "MULTICHANNEL": "multichannel"
                    },
                    ('source',): {

                        "API": "api",
                        "EXCEL": "excel",
                        "WEBAPP": "webapp",
                        "SMPP": "smpp",
                        "PLUGIN": "plugin",
                        "ALERTS": "alerts"
                    },
                    ('delivery_report',): {

                        "DELIVERED": "delivered",
                        "FAILED": "failed",
                        "SENT": "sent",
                        "ACCEPTED": "accepted",
                        "REJECTED": "rejected",
                        "SCHEDULED": "scheduled"
                    },
                },
                'api_types': {
                    'period':
                        (str,),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'channel':
                        (str,),
                    'source':
                        (str,),
                    'delivery_report':
                        (str,),
                    'country_iso':
                        (str,),
                    'short_response':
                        (bool,),
                    'limit':
                        (int,),
                    'next':
                        (str,),
                    'previous':
                        (str,),
                },
                'attribute_map': {
                    'period': 'period',
                    'start_date': 'start_date',
                    'end_date': 'end_date',
                    'channel': 'channel',
                    'source': 'source',
                    'delivery_report': 'delivery_report',
                    'country_iso': 'country_iso',
                    'short_response': 'short_response',
                    'limit': 'limit',
                    'next': 'next',
                    'previous': 'previous',
                },
                'location_map': {
                    'period': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'channel': 'query',
                    'source': 'query',
                    'delivery_report': 'query',
                    'country_iso': 'query',
                    'short_response': 'query',
                    'limit': 'query',
                    'next': 'query',
                    'previous': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_campaign_report_endpoint = _Endpoint(
            settings={
                'response_type': (ReportsCampaignResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/campaigns/{campaignId}',
                'operation_id': 'get_campaign_report',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'campaign_id',
                    'short_response',
                    'limit',
                    'next',
                    'previous',
                ],
                'required': [
                    'campaign_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'campaign_id',
                ]
            },
            root_map={
                'validations': {
                    ('campaign_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'campaign_id':
                        (str,),
                    'short_response':
                        (bool,),
                    'limit':
                        (int,),
                    'next':
                        (str,),
                    'previous':
                        (str,),
                },
                'attribute_map': {
                    'campaign_id': 'campaignId',
                    'short_response': 'short_response',
                    'limit': 'limit',
                    'next': 'next',
                    'previous': 'previous',
                },
                'location_map': {
                    'campaign_id': 'path',
                    'short_response': 'query',
                    'limit': 'query',
                    'next': 'query',
                    'previous': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_campaigns_list_endpoint = _Endpoint(
            settings={
                'response_type': (ReportsCampaignsRespone,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/campaigns',
                'operation_id': 'get_campaigns_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'delivery_reports',
                    'source',
                    'limit',
                    'next',
                    'previous',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'source',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('source',): {

                        "API": "api",
                        "EXCEL": "excel",
                        "WEBAPP": "webapp",
                        "SMPP": "smpp",
                        "PLUGIN": "plugin",
                        "ALERTS": "alerts"
                    },
                },
                'api_types': {
                    'delivery_reports':
                        (bool,),
                    'source':
                        (str,),
                    'limit':
                        (int,),
                    'next':
                        (str,),
                    'previous':
                        (str,),
                },
                'attribute_map': {
                    'delivery_reports': 'delivery_reports',
                    'source': 'source',
                    'limit': 'limit',
                    'next': 'next',
                    'previous': 'previous',
                },
                'location_map': {
                    'delivery_reports': 'query',
                    'source': 'query',
                    'limit': 'query',
                    'next': 'query',
                    'previous': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_single_report_endpoint = _Endpoint(
            settings={
                'response_type': (ReportSingleResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/single/{msgId}',
                'operation_id': 'get_single_report',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'msg_id',
                ],
                'required': [
                    'msg_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'msg_id',
                ]
            },
            root_map={
                'validations': {
                    ('msg_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'msg_id':
                        (str,),
                },
                'attribute_map': {
                    'msg_id': 'msgId',
                },
                'location_map': {
                    'msg_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_summary_reports_endpoint = _Endpoint(
            settings={
                'response_type': (GetSummaryReports200Response,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/reports/summary/{dimension}',
                'operation_id': 'get_summary_reports',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'dimension',
                    'period',
                    'start_date',
                    'end_date',
                    'limit',
                ],
                'required': [
                    'dimension',
                    'period',
                    'start_date',
                    'end_date',
                ],
                'nullable': [
                ],
                'enum': [
                    'dimension',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('dimension',): {

                        "SOURCE": "source",
                        "CHANNEL": "channel",
                        "COUNTRY": "country",
                        "TRAFFIC": "traffic",
                        "DELIVERY": "delivery"
                    },
                },
                'api_types': {
                    'dimension':
                        (str,),
                    'period':
                        (str,),
                    'start_date':
                        (str,),
                    'end_date':
                        (str,),
                    'limit':
                        (int,),
                },
                'attribute_map': {
                    'dimension': 'dimension',
                    'period': 'period',
                    'start_date': 'start_date',
                    'end_date': 'end_date',
                    'limit': 'limit',
                },
                'location_map': {
                    'dimension': 'path',
                    'period': 'query',
                    'start_date': 'query',
                    'end_date': 'query',
                    'limit': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def export_advanced_report_to_csv(
        self,
        period,
        start_date,
        end_date,
        **kwargs
    ):
        """Export advanced report to CSV  # noqa: E501

        Exports the report for for the specified filters to a CSV file.  The only required parameters are the dates filters: `period` parameter or `start_date` and `end_date`.    If no data is available for the report, an empty CSV file is returned (with first line headers).    
### Errors for GET `/reports/csv`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1820  |  invalid_param  |  The parameter `period` is not a valid date (format Y-m or Y) |  

|  400 | 1821  |  invalid_param  |  The parameter `start_date` is not a valid date |  

|  400 | 1822  |  invalid_param  |  The parameter `end_date` is not a valid date |  

|  400 | 1823  |  invalid_param  |  The end date is before the start date |  

|  400 | 1824  |  invalid_param  |  No `period` parameter or interval (`start_date`, `end_date`) |  

|  400 | 1825  |  invalid_param  |  The parameter `source` is not valid |  

|  400 | 1826  |  invalid_param  |  The parameter `delivery_report` is not valid (delivered, failed or sent) |  

|  400 | 1827  |  invalid_param  |  The parameter `country_iso` is not for a valid country  |  

|  400 | 1828  |  invalid_param  |  The parameter `channel` is not valid (sms, viber, whatsapp, multichannel) |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_advanced_report_to_csv(period, start_date, end_date, async_req=True)
        >>> result = thread.get()

        Args:
            period (str): Period for the requested report in format **Y-M** or **Y**
            start_date (str): The start date of the report in format Y-M-D
            end_date (str): The end date of the report in format Y-M-D

        Keyword Args:
            channel (str): Channel of the sent messages. [optional]
            source (str): Source of the sent messages. [optional]
            delivery_report (str): . [optional]
            country_iso (str): Two-letter country code defined in ISO-3166 alpha 2 standard (case insensitive). [optional]
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['period'] = \
            period
        kwargs['start_date'] = \
            start_date
        kwargs['end_date'] = \
            end_date
        return self.export_advanced_report_to_csv_endpoint.call_with_http_info(**kwargs)

    def export_advanced_report_to_xlsx(
        self,
        period,
        start_date,
        end_date,
        **kwargs
    ):
        """Export advanced report to XLSX  # noqa: E501

        Exports the report for for the specified filters to a XLSX file (Excel).  The only required parameters are the dates filters: `period` parameter or `start_date` and `end_date`.    If no data is available for the report, an empty XLSX file is returned (with first line headers).    
### Errors for GET `/reports/xlsx`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1820  |  invalid_param  |  The parameter `period` is not a valid date (format Y-m or Y) |  

|  400 | 1821  |  invalid_param  |  The parameter `start_date` is not a valid date |  

|  400 | 1822  |  invalid_param  |  The parameter `end_date` is not a valid date |  

|  400 | 1823  |  invalid_param  |  The end date is before the start date |  

|  400 | 1824  |  invalid_param  |  No `period` parameter or interval (`start_date`, `end_date`) |  

|  400 | 1825  |  invalid_param  |  The parameter `source` is not valid |  

|  400 | 1826  |  invalid_param  |  The parameter `delivery_report` is not valid (delivered, failed or sent) |  

|  400 | 1827  |  invalid_param  |  The parameter `country_iso` is not for a valid country  |  

|  400 | 1828  |  invalid_param  |  The parameter `channel` is not valid (sms, viber, whatsapp, multichannel) |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_advanced_report_to_xlsx(period, start_date, end_date, async_req=True)
        >>> result = thread.get()

        Args:
            period (str): Period for the requested report in format **Y-M** or **Y**
            start_date (str): The start date of the report in format Y-M-D
            end_date (str): The end date of the report in format Y-M-D

        Keyword Args:
            channel (str): Channel of the sent messages. [optional]
            source (str): Source of the sent messages. [optional]
            delivery_report (str): . [optional]
            country_iso (str): Two-letter country code defined in ISO-3166 alpha 2 standard (case insensitive). [optional]
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['period'] = \
            period
        kwargs['start_date'] = \
            start_date
        kwargs['end_date'] = \
            end_date
        return self.export_advanced_report_to_xlsx_endpoint.call_with_http_info(**kwargs)

    def export_campaign_report_to_csv(
        self,
        campaign_id,
        **kwargs
    ):
        """Export campaign report to CSV  # noqa: E501

        Exports the details of a sent campaign to a CSV file.    
### Errors for GET `/reports/campaigns/{campaignId}/csv`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1160  |  not_found  |  Campaign ID or msg ID provided was not found  |    

|  400 | 1165  |  invalid_param  |  Campaign ID or msg ID provided is not valid  |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_campaign_report_to_csv(campaign_id, async_req=True)
        >>> result = thread.get()

        Args:
            campaign_id (str): Identifier of a sent campaign

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['campaign_id'] = \
            campaign_id
        return self.export_campaign_report_to_csv_endpoint.call_with_http_info(**kwargs)

    def export_campaign_report_to_xlsx(
        self,
        campaign_id,
        **kwargs
    ):
        """Export campaign report to XLSX  # noqa: E501

        Exports the details of a sent campaign to a XLSX file (Excel).    
### Errors for GET `/reports/campaigns/{campaignId}/xlsx`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1160  |  not_found  |  Campaign ID or msg ID provided was not found  |    

|  400 | 1165  |  invalid_param  |  Campaign ID or msg ID provided is not valid  |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_campaign_report_to_xlsx(campaign_id, async_req=True)
        >>> result = thread.get()

        Args:
            campaign_id (str): Identifier of a sent campaign

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['campaign_id'] = \
            campaign_id
        return self.export_campaign_report_to_xlsx_endpoint.call_with_http_info(**kwargs)

    def get_advanced_report(
        self,
        period,
        start_date,
        end_date,
        **kwargs
    ):
        """Get advanced report  # noqa: E501

        Retrieves the report for the specified filters.  The only required parameters are the dates filters: `period` parameter or `start_date` and `end_date`.    If no data is available for the report, an empty data object is returned.    
### Errors for GET `/reports`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1820  |  invalid_param  |  The parameter `period` is not a valid date (format Y-m or Y) |  

|  400 | 1821  |  invalid_param  |  The parameter `start_date` is not a valid date |  

|  400 | 1822  |  invalid_param  |  The parameter `end_date` is not a valid date |  

|  400 | 1823  |  invalid_param  |  The end date is before the start date |  

|  400 | 1824  |  invalid_param  |  No `period` parameter or interval (`start_date`, `end_date`) |  

|  400 | 1825  |  invalid_param  |  The parameter `source` is not valid |  

|  400 | 1826  |  invalid_param  |  The parameter `delivery_report` is not valid (delivered, failed or sent) |  

|  400 | 1827  |  invalid_param  |  The parameter `country_iso` is not for a valid country  |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_advanced_report(period, start_date, end_date, async_req=True)
        >>> result = thread.get()

        Args:
            period (str): Period for the requested report in format **Y-M** or **Y**
            start_date (str): The start date of the report in format Y-M-D
            end_date (str): The end date of the report in format Y-M-D

        Keyword Args:
            channel (str): Channel of the sent messages. [optional]
            source (str): Source of the sent messages. [optional]
            delivery_report (str): . [optional]
            country_iso (str): Two-letter country code defined in ISO-3166 alpha 2 standard (case insensitive). [optional]
            short_response (bool): If set to true, it will return the full `info` object and an empty `data` object. [optional] if omitted the server will use the default value of False
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            next (str): The next token used to retrieve additional data. [optional]
            previous (str): The previous token used to retrieve additional data. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ReportsAdvancedResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['period'] = \
            period
        kwargs['start_date'] = \
            start_date
        kwargs['end_date'] = \
            end_date
        return self.get_advanced_report_endpoint.call_with_http_info(**kwargs)

    def get_campaign_report(
        self,
        campaign_id,
        **kwargs
    ):
        """Get campaign report  # noqa: E501

        Returns the details of a sent campaign if a valid identifier was provided.    
### Errors for GET `/reports/campaigns/{campaignId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1150  |  not_found  |  Campaign ID provided was not found |  

|  400 | 1155  |  invalid_param  |  Campaign ID provided is not valid |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_campaign_report(campaign_id, async_req=True)
        >>> result = thread.get()

        Args:
            campaign_id (str): Identifier of a sent campaign

        Keyword Args:
            short_response (bool): If set to true, it will return the full `info` object and an empty `data` object. [optional] if omitted the server will use the default value of False
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            next (str): The next token used to retrieve additional data. [optional]
            previous (str): The previous token used to retrieve additional data. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ReportsCampaignResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['campaign_id'] = \
            campaign_id
        return self.get_campaign_report_endpoint.call_with_http_info(**kwargs)

    def get_campaigns_list(
        self,
        **kwargs
    ):
        """Get list of sent campaigns  # noqa: E501

        Returns a list of sent Campaigns, with the most recent appearing first.    If no data is available, an empty data object is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_campaigns_list(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            delivery_reports (bool): The response will contain an object **data.status** with delivery report summary for each campaign. [optional] if omitted the server will use the default value of False
            source (str): Source of the sent messages. [optional]
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            next (str): The next token used to retrieve additional data. [optional]
            previous (str): The previous token used to retrieve additional data. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ReportsCampaignsRespone
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_campaigns_list_endpoint.call_with_http_info(**kwargs)

    def get_single_report(
        self,
        msg_id,
        **kwargs
    ):
        """Get report for single SMS or Viber or Whatsapp or Multichannel  # noqa: E501

        Returns the details of a single message if a valid identifier was provided.    
### Errors for GET `/reports/single/{msgId} `  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1160  |  not_found  |  Campaign ID or msg ID provided was not found  |    

|  400 | 1165  |  invalid_param  |  Campaign ID or msg ID provided is not valid  |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_single_report(msg_id, async_req=True)
        >>> result = thread.get()

        Args:
            msg_id (str): Identifier of a sent message

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ReportSingleResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['msg_id'] = \
            msg_id
        return self.get_single_report_endpoint.call_with_http_info(**kwargs)

    def get_summary_reports(
        self,
        dimension,
        period,
        start_date,
        end_date,
        **kwargs
    ):
        """Get summary reports for a dimension  # noqa: E501

        Retrieves a summary report for the specified dimensions.    The only required parameters are the dates for the report. The date filters can be: with `period` parameter or with `start_date` and `end_date`    For some dimensions (**traffic** and **delivery**) the summary report will aggregate on dates.   If the summary report was requested with **period** parameter, the dates will be months or days.  If it was requested with interval **start_date** - **end_date**, the dates will be the days between the interval.    Eg. period=2011, the property will be all months in the year  period=2011-06, the property will be all days in month   start_date=2021-06-15, end_date=2021-06-30, the properties will be all days between the interval      If no data is available for the summary report an empty data object is returned.      
### Errors for GET `/reports/summary/{dimension}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1829  |  invalid_param  |  Invalid dimension. Accepted dimensions: source, channel, country, traffic, delivery |    

|  400 | 1820  |  invalid_param  |  The parameter `period` is not a valid date (format Y-m or Y) |  

|  400 | 1821  |  invalid_param  |  The parameter `start_date` is not a valid date |  

|  400 | 1822  |  invalid_param  |  The parameter `end_date` is not a valid date |  

|  400 | 1823  |  invalid_param  |  The end date is before the start date |  

|  400 | 1824  |  invalid_param  |  No `period` parameter or interval (`start_date`, `end_date`) |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_summary_reports(dimension, period, start_date, end_date, async_req=True)
        >>> result = thread.get()

        Args:
            dimension (str): Dimension for wich the summary report is requested
            period (str): Period for the requested report in format **Y-M** or **Y**
            start_date (str): The start date of the report in format Y-M-D
            end_date (str): The end date of the report in format Y-M-D

        Keyword Args:
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GetSummaryReports200Response
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['dimension'] = \
            dimension
        kwargs['period'] = \
            period
        kwargs['start_date'] = \
            start_date
        kwargs['end_date'] = \
            end_date
        return self.get_summary_reports_endpoint.call_with_http_info(**kwargs)





# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from smscx_client.api.account_api import AccountApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from smscx_client.api.account_api import AccountApi
from smscx_client.api.applications_api import ApplicationsApi
from smscx_client.api.attachments_api import AttachmentsApi
from smscx_client.api.conversations_api import ConversationsApi
from smscx_client.api.groups_api import GroupsApi
from smscx_client.api.multichannel_api import MultichannelApi
from smscx_client.api.numbers_api import NumbersApi
from smscx_client.api.oauth_api import OauthApi
from smscx_client.api.optouts_api import OptoutsApi
from smscx_client.api.originators_api import OriginatorsApi
from smscx_client.api.otp_api import OtpApi
from smscx_client.api.reports_api import ReportsApi
from smscx_client.api.shortlinks_api import ShortlinksApi
from smscx_client.api.sms_api import SmsApi
from smscx_client.api.templates_api import TemplatesApi
from smscx_client.api.viber_api import ViberApi
from smscx_client.api.whatsapp_api import WhatsappApi



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.delete_scheduled_campaign import DeleteScheduledCampaign
from smscx_client.model.delete_scheduled_msg import DeleteScheduledMsg
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model403_no_coverage import Model403NoCoverage
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.send_sms_campaign_request import SendSmsCampaignRequest
from smscx_client.model.send_sms_campaign_request_estimate import SendSmsCampaignRequestEstimate
from smscx_client.model.send_sms_campaign_response import SendSmsCampaignResponse
from smscx_client.model.send_sms_message_request import SendSmsMessageRequest
from smscx_client.model.send_sms_message_response import SendSmsMessageResponse
from smscx_client.model.send_sms_request_estimate import SendSmsRequestEstimate


class SmsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.delete_scheduled_sms_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteScheduledMsg,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/sms/scheduled/{msgId}',
                'operation_id': 'delete_scheduled_sms',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'msg_id',
                ],
                'required': [
                    'msg_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'msg_id',
                ]
            },
            root_map={
                'validations': {
                    ('msg_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'msg_id':
                        (str,),
                },
                'attribute_map': {
                    'msg_id': 'msgId',
                },
                'location_map': {
                    'msg_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_scheduled_sms_campaign_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteScheduledCampaign,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/sms/scheduled/campaign/{campaignId}',
                'operation_id': 'delete_scheduled_sms_campaign',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'campaign_id',
                ],
                'required': [
                    'campaign_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'campaign_id',
                ]
            },
            root_map={
                'validations': {
                    ('campaign_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'campaign_id':
                        (str,),
                },
                'attribute_map': {
                    'campaign_id': 'campaignId',
                },
                'location_map': {
                    'campaign_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.estimate_sms_endpoint = _Endpoint(
            settings={
                'response_type': (SendSmsMessageResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/sms/estimate',
                'operation_id': 'estimate_sms',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'send_sms_request_estimate',
                ],
                'required': [
                    'send_sms_request_estimate',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'send_sms_request_estimate':
                        (SendSmsRequestEstimate,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'send_sms_request_estimate': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.estimate_sms_campaign_endpoint = _Endpoint(
            settings={
                'response_type': (SendSmsCampaignResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/sms/campaign/estimate',
                'operation_id': 'estimate_sms_campaign',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'send_sms_campaign_request_estimate',
                ],
                'required': [
                    'send_sms_campaign_request_estimate',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'send_sms_campaign_request_estimate':
                        (SendSmsCampaignRequestEstimate,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'send_sms_campaign_request_estimate': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.send_sms_endpoint = _Endpoint(
            settings={
                'response_type': (SendSmsMessageResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/sms',
                'operation_id': 'send_sms',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'send_sms_message_request',
                ],
                'required': [
                    'send_sms_message_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'send_sms_message_request':
                        (SendSmsMessageRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'send_sms_message_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.send_sms_campaign_endpoint = _Endpoint(
            settings={
                'response_type': (SendSmsCampaignResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/sms/campaign',
                'operation_id': 'send_sms_campaign',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'send_sms_campaign_request',
                ],
                'required': [
                    'send_sms_campaign_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'send_sms_campaign_request':
                        (SendSmsCampaignRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'send_sms_campaign_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def delete_scheduled_sms(
        self,
        msg_id,
        **kwargs
    ):
        """Delete scheduled SMS  # noqa: E501

        Delete a scheduled SMS by providing a valid identifier (`msgId`).    The cost of the deleted scheduled SMS will be returned to the balance of the account.    
### Errors for DELETE `/sms/scheduled/{msgId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  403 | 1118  |  access_denied  |  Only scheduled campaigns/messages can be deleted |  
|  404 | 1100  |  not_found  |  Message ID provided was not found or is not scheduled |  

|  400 | 1115  |  invalid_param  |  Message ID provided is not valid |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_scheduled_sms(msg_id, async_req=True)
        >>> result = thread.get()

        Args:
            msg_id (str): Identifier of a scheduled message

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeleteScheduledMsg
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['msg_id'] = \
            msg_id
        return self.delete_scheduled_sms_endpoint.call_with_http_info(**kwargs)

    def delete_scheduled_sms_campaign(
        self,
        campaign_id,
        **kwargs
    ):
        """Delete scheduled SMS campaign  # noqa: E501

        Delete a scheduled SMS campaign by providing a valid identifier (`campaignId`).    The cost of the deleted scheduled SMS campaign will be returned to the balance of the account.    If part of the SMS campaign has already started, only scheduled messages will be deleted. Messages already sent cannot be deleted.    
### Errors for DELETE `/sms/scheduled/campaign/{campaignId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  403 | 1118  |  access_denied  |  Only scheduled campaigns/messages can be deleted |  
|  404 | 1150  |  not_found  |  Campaign ID provided was not found or is not scheduled |  

|  400 | 1155  |  invalid_param  |  Campaign ID provided is not valid |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_scheduled_sms_campaign(campaign_id, async_req=True)
        >>> result = thread.get()

        Args:
            campaign_id (str): Identifier of a scheduled SMS campaign

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeleteScheduledCampaign
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['campaign_id'] = \
            campaign_id
        return self.delete_scheduled_sms_campaign_endpoint.call_with_http_info(**kwargs)

    def estimate_sms(
        self,
        send_sms_request_estimate,
        **kwargs
    ):
        """Estimate new SMS  # noqa: E501

        Estimate the cost of sending a SMS message.    This endpoint is identical to `/sms` endpoint, but it will only simulate the SMS sending (no billing).    The request body and the response are the same as for `/sms` endpoint.    ```  curl --location --request POST 'https://api.sms.cx/sms/estimate' \\  --header 'Authorization: Bearer d34a5e82f8d5e45ad1968deb5d3a3674ea6b46f6' \\  --header 'Content-Type: application/json' \\  --data-raw '{      \"to\": [          \"+31612469822\",          \"+31612469333\"      ],      \"from\": \"InfoText\",      \"text\": \"Second text message\"  }'  ```    
### Errors for POST `/sms/estimate`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1104  |  invalid_param  | The parameter `to` is empty or not set |  

|  400 | 1105  |  invalid_param  |  The parameter `from` is empty or not set |  

|  400 | 1106  |  invalid_param  |  The parameter `from` is not valid (min 3, max 15 characters) |  

|  400 | 1107  |  invalid_param  |  The parameter `text` is empty or not set |  

|  400 | 1108  |  invalid_param  |  The parameter `scheduledDate` is not a valid date |  

|  400 | 1109  |  invalid_param  |  The parameter `dlrCallbackUrl` is not a valid URL |  

|  400 | 1112  |  invalid_param  |  The shortlink/attachment ID provided for tracking is invalid or not found |  

|  400 | 1116  |  invalid_param  |  The scheduled date is in the past |  

|  400 | 1103  |  invalid_param  |  The phone numbers array is too big (max. allowed: 25000 numbers) |  

|  400 | 1207  |  invalid_param  | The phone number provided is not valid |  

|  400 | 1210  |  invalid_param  |  The phone numbers provided are invalid |  
|  403 | 1119  |  no_coverage  |  No coverage or restricted destination |  

|  400 | 1113  |  insufficient_credit  |  Insufficient credit |  

|  400 | 1114  |  insufficient_credit  |  Credit limit reached. To increase the credit limit, please contact your account manager |  
| 400 | 1110 | invalid_param | Invalid alphabet. Must be one of: `NONE`, `NON_GSM`, `RUSSIAN_CYRILLIC`, `BULGARIAN_CYRILLIC`, `UKRAINIAN_CYRILLIC`, `MACEDONIAN_CYRILLIC`, `BELARUSIAN_CYRILLIC`, `SERBIAN_CYRILLIC`, `POLISH`, `ROMANIAN`, `TURKISH`, `GREEK` |  
| 400 | 1135 | invalid_param | The parameter \\'transliteration\\' should be an object |   
| 400 | 1503 | invalid_param | The parameter `removeEmojis` is not boolean (true or false) |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{numbers}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{letters}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{alphanumeric}} |  

|  400 | 1137  |  invalid_param  |  Number of characters for placeholders can be between 1 and 20 |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.estimate_sms(send_sms_request_estimate, async_req=True)
        >>> result = thread.get()

        Args:
            send_sms_request_estimate (SendSmsRequestEstimate): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SendSmsMessageResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['send_sms_request_estimate'] = \
            send_sms_request_estimate
        return self.estimate_sms_endpoint.call_with_http_info(**kwargs)

    def estimate_sms_campaign(
        self,
        send_sms_campaign_request_estimate,
        **kwargs
    ):
        """Estimate SMS campaign  # noqa: E501

        Estimate the cost of sending a SMS message to groups of phone numbers.    This endpoint is identical to `/sms/campaign` endpoint, but it will only simulate the SMS sending (no billing).    The request body and the response are the same as for `/sms/campaign` endpoint.    
### Errors for POST `/sms/campaign/estimate`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1101  |  invalid_param  |  The parameter `groups` is empty or not set |  

|  400 | 1140  |  invalid_param  |  Group ID is not a valid group |  

|  400 | 1102  |  invalid_param  |  Group is empty |  

|  400 | 1103  |  invalid_param  |  The phone numbers array is too big (max. allowed: 25000 numbers) |  

|  400 | 1105  |  invalid_param  |  The parameter `from` is empty or not set |  

|  400 | 1106  |  invalid_param  |  The parameter `from` is not valid (min 3, max 15 characters) |  

|  400 | 1107  |  invalid_param  |  The parameter `text` is empty or not set |  

|  400 | 1108  |  invalid_param  |  The parameter `scheduledDate` is not a valid date |  

|  400 | 1109  |  invalid_param  |  The parameter `dlrCallbackUrl` is not a valid URL |  

|  400 | 1112  |  invalid_param  |  The shortlink/attachment ID provided for tracking is invalid or not found |  

|  400 | 1116  |  invalid_param  |  The scheduled date is in the past |  
|  403 | 1119  |  no_coverage  |  No coverage or restricted destination |  

|  400 | 1113  |  insufficient_credit  |  Insufficient credit |  

|  400 | 1114  |  insufficient_credit  |  Credit limit reached. To increase the credit limit, please contact your account manager |  
| 400 | 1110 | invalid_param | Invalid alphabet. Must be one of: `NONE`, `NON_GSM`, `RUSSIAN_CYRILLIC`, `BULGARIAN_CYRILLIC`, `UKRAINIAN_CYRILLIC`, `MACEDONIAN_CYRILLIC`, `BELARUSIAN_CYRILLIC`, `SERBIAN_CYRILLIC`, `POLISH`, `ROMANIAN`, `TURKISH`, `GREEK` |  
| 400 | 1135 | invalid_param | The parameter \\'transliteration\\' should be an object |   
| 400 | 1503 | invalid_param | The parameter `removeEmojis` is not boolean (true or false) |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{numbers}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{letters}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{alphanumeric}} |  

|  400 | 1137  |  invalid_param  |  Number of characters for placeholders can be between 1 and 20 |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.estimate_sms_campaign(send_sms_campaign_request_estimate, async_req=True)
        >>> result = thread.get()

        Args:
            send_sms_campaign_request_estimate (SendSmsCampaignRequestEstimate): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SendSmsCampaignResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['send_sms_campaign_request_estimate'] = \
            send_sms_campaign_request_estimate
        return self.estimate_sms_campaign_endpoint.call_with_http_info(**kwargs)

    def send_sms(
        self,
        send_sms_message_request,
        **kwargs
    ):
        """Send SMS  # noqa: E501

        Sends SMS to a single phone number or to a list of phone numbers.    This endpoint was designed to handle big data objects (up to 25.000 SMS in one request).    If you have loops or iterations we recommend building the send object in your application, and make a single request to this endpoint. The time of making the requests will decrease - by doing a single request with multiple send objects vs making requests in a loop -  and you won't have to worry about making concurrent API calls.    > Note: This endpoint accepts idempotent requests by providing an additional `idempotencyId` parameter in body with a unique value generated by the client of type UUID v1-v5. To confirm that the server understood the request, the response will contain the header `X-Idempotency-Id` with your unique value.  By using idempotency you can retry requests in case of network error or server not responding in time, without accidentally performing the same operation twice and have a guarantee of not being billed twice.     
### Errors for POST `/sms`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1103  |  invalid_param  |  The phone numbers array is too big (max. allowed: 25000 numbers) |  

|  400 | 1104  |  invalid_param  | The parameter `to` is empty or not set |  

|  400 | 1105  |  invalid_param  |  The parameter `from` is empty or not set |  

|  400 | 1106  |  invalid_param  |  The parameter `from` is not valid (min 3, max 15 characters) |  

|  400 | 1107  |  invalid_param  |  The parameter `text` is empty or not set |  

|  400 | 1108  |  invalid_param  |  The parameter `scheduledDate` is not a valid date |  

|  400 | 1109  |  invalid_param  |  The parameter `dlrCallbackUrl` is not a valid URL |  

|  400 | 1111  |  invalid_param  |  Idempotency Id provided is not a valid UUID (v1-v5) |  

|  400 | 1112  |  invalid_param  |  The shortlink/attachment ID provided for tracking is invalid or not found |  

|  400 | 1116  |  invalid_param  |  The scheduled date is in the past |  

|  400 | 1207  |  invalid_param  | The phone number provided is not valid |  

|  400 | 1210  |  invalid_param  |  The phone numbers provided are invalid |  
|  403 | 1119  |  no_coverage  |  No coverage or restricted destination |  

|  400 | 1113  |  insufficient_credit  |  Insufficient credit |  

|  400 | 1114  |  insufficient_credit  |  Credit limit reached. To increase the credit limit, please contact your account manager |  
| 400 | 1110 | invalid_param | Invalid alphabet. Must be one of: `NONE`, `NON_GSM`, `RUSSIAN_CYRILLIC`, `BULGARIAN_CYRILLIC`, `UKRAINIAN_CYRILLIC`, `MACEDONIAN_CYRILLIC`, `BELARUSIAN_CYRILLIC`, `SERBIAN_CYRILLIC`, `POLISH`, `ROMANIAN`, `TURKISH`, `GREEK` |  
| 400 | 1135 | invalid_param | The parameter \\'transliteration\\' should be an object |   
| 400 | 1503 | invalid_param | The parameter `removeEmojis` is not boolean (true or false) |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{numbers}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{letters}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{alphanumeric}} |  

|  400 | 1137  |  invalid_param  |  Number of characters for placeholders can be between 1 and 20 |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_sms(send_sms_message_request, async_req=True)
        >>> result = thread.get()

        Args:
            send_sms_message_request (SendSmsMessageRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SendSmsMessageResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['send_sms_message_request'] = \
            send_sms_message_request
        return self.send_sms_endpoint.call_with_http_info(**kwargs)

    def send_sms_campaign(
        self,
        send_sms_campaign_request,
        **kwargs
    ):
        """Send SMS campaign  # noqa: E501

        <a name=\"post-sms-campaign\"></a>    Sends SMS to existing group(s) of contacts.    > Note: This endpoint accepts idempotent requests by providing an additional `idempotencyId` parameter in body with a unique value generated by the client of type UUID v1-v5. To confirm that the server understood the request, the response will contain the header `X-Idempotency-Id` with your unique value.  By using idempotency you can retry requests in case of network error or server not responding in time, without accidentally performing the same operation twice and have a guarantee of not being billed twice.     > We recommend to always use Idempotency ID when sending SMS campaigns      
### Errors for POST `/sms/campaign`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1101  |  invalid_param  |  The parameter `groups` is empty or not set |  

|  400 | 1140  |  invalid_param  |  Group ID is not a valid group |  

|  400 | 1102  |  invalid_param  |  Group is empty |  

|  400 | 1103  |  invalid_param  |  The phone numbers array is too big (max. allowed: 25000 numbers) |  

|  400 | 1105  |  invalid_param  |  The parameter `from` is empty or not set |  

|  400 | 1106  |  invalid_param  |  The parameter `from` is not valid (min 3, max 15 characters) |  

|  400 | 1107  |  invalid_param  |  The parameter `text` is empty or not set |  

|  400 | 1108  |  invalid_param  |  The parameter `scheduledDate` is not a valid date |  

|  400 | 1109  |  invalid_param  |  The parameter `dlrCallbackUrl` is not a valid URL |  

|  400 | 1111  |  invalid_param  |  Idempotency Id provided is not a valid UUID (v1-v5) |  

|  400 | 1112  |  invalid_param  |  The shortlink/attachment ID provided for tracking is invalid or not found |  

|  400 | 1116  |  invalid_param  |  The scheduled date is in the past |  
|  403 | 1119  |  no_coverage  |  No coverage or restricted destination |  

|  400 | 1113  |  insufficient_credit  |  Insufficient credit |  

|  400 | 1114  |  insufficient_credit  |  Credit limit reached. To increase the credit limit, please contact your account manager |  
| 400 | 1110 | invalid_param | Invalid alphabet. Must be one of: `NONE`, `NON_GSM`, `RUSSIAN_CYRILLIC`, `BULGARIAN_CYRILLIC`, `UKRAINIAN_CYRILLIC`, `MACEDONIAN_CYRILLIC`, `BELARUSIAN_CYRILLIC`, `SERBIAN_CYRILLIC`, `POLISH`, `ROMANIAN`, `TURKISH`, `GREEK` |  
| 400 | 1135 | invalid_param | The parameter \\'transliteration\\' should be an object |   
| 400 | 1503 | invalid_param | The parameter `removeEmojis` is not boolean (true or false) |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{numbers}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{letters}} |  

|  400 | 1136  |  invalid_param  |  Invalid number of characters for the placeholder {{alphanumeric}} |  

|  400 | 1137  |  invalid_param  |  Number of characters for placeholders can be between 1 and 20 |    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.send_sms_campaign(send_sms_campaign_request, async_req=True)
        >>> result = thread.get()

        Args:
            send_sms_campaign_request (SendSmsCampaignRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SendSmsCampaignResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['send_sms_campaign_request'] = \
            send_sms_campaign_request
        return self.send_sms_campaign_endpoint.call_with_http_info(**kwargs)




import unittest

import smscx_client
from smscx_client.api.viber_api import ViberApi  # noqa: E501


class TestViberApi(unittest.TestCase):
    """ViberApi unit test stubs"""

    def setUp(self):
        self.api = ViberApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_scheduled_viber_campaign(self):
        """Test case for delete_scheduled_viber_campaign

        Delete scheduled Viber campaign  # noqa: E501
        """
        pass

    def test_delete_scheduled_viber_message(self):
        """Test case for delete_scheduled_viber_message

        Delete scheduled Viber message  # noqa: E501
        """
        pass

    def test_estimate_viber_campaign(self):
        """Test case for estimate_viber_campaign

        Estimate Viber campaign  # noqa: E501
        """
        pass

    def test_estimate_viber_message(self):
        """Test case for estimate_viber_message

        Estimate Viber message  # noqa: E501
        """
        pass

    def test_send_viber_campaign(self):
        """Test case for send_viber_campaign

        Send Viber campaign  # noqa: E501
        """
        pass

    def test_send_viber_message(self):
        """Test case for send_viber_message

        Send Viber message  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.templates_api import TemplatesApi  # noqa: E501


class TestTemplatesApi(unittest.TestCase):
    """TemplatesApi unit test stubs"""

    def setUp(self):
        self.api = TemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_template(self):
        """Test case for create_template

        Create template  # noqa: E501
        """
        pass

    def test_delete_template(self):
        """Test case for delete_template

        Delete template  # noqa: E501
        """
        pass

    def test_get_template(self):
        """Test case for get_template

        Get template  # noqa: E501
        """
        pass

    def test_get_templates_list(self):
        """Test case for get_templates_list

        Get templates list  # noqa: E501
        """
        pass

    def test_update_template(self):
        """Test case for update_template

        Update template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.settings import Settings
globals()['Settings'] = Settings
from smscx_client.model.application_settings_response import ApplicationSettingsResponse


class TestApplicationSettingsResponse(unittest.TestCase):
    """ApplicationSettingsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApplicationSettingsResponse(self):
        """Test ApplicationSettingsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApplicationSettingsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_new_optout import DataNewOptout
globals()['DataNewOptout'] = DataNewOptout
from smscx_client.model.call_back_request_new_optout import CallBackRequestNewOptout


class TestCallBackRequestNewOptout(unittest.TestCase):
    """CallBackRequestNewOptout unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCallBackRequestNewOptout(self):
        """Test CallBackRequestNewOptout"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CallBackRequestNewOptout()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_new_group import InfoNewGroup
globals()['InfoNewGroup'] = InfoNewGroup
from smscx_client.model.new_group_response import NewGroupResponse


class TestNewGroupResponse(unittest.TestCase):
    """NewGroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewGroupResponse(self):
        """Test NewGroupResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NewGroupResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError



class DataMultichannel(ModelNormal):


    allowed_values = {
        ('status',): {
            'ACCEPTED': "ACCEPTED",
            'SCHEDULED': "SCHEDULED",
            'REJECTED': "REJECTED",
            'NO_COVERAGE': "NO COVERAGE",
        },
        ('channel',): {
            'VIBER': "viber",
            'WHATSAPP': "whatsapp",
            'SMS': "sms",
        },
    }

    validations = {
        ('msg_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
        ('country_iso',): {
            'max_length': 2,
            'min_length': 2,
        },
        ('_from',): {
            'max_length': 15,
            'min_length': 3,
        },
        ('parts',): {
            'inclusive_maximum': 1,
            'inclusive_minimum': 1,
        },
        ('track_data',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
    }

    @cached_property
    def additional_properties_type():
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'msg_id': (str,),  # noqa: E501
            'status': (str,),  # noqa: E501
            'status_code': (int,),  # noqa: E501
            'error_code': (int, none_type,),  # noqa: E501
            'created_at': (datetime,),  # noqa: E501
            'in_quiet_hours': (bool,),  # noqa: E501
            'cost': (float,),  # noqa: E501
            'to': (str,),  # noqa: E501
            'country_iso': (str,),  # noqa: E501
            '_from': (str,),  # noqa: E501
            'text': (str,),  # noqa: E501
            'parts': (int,),  # noqa: E501
            'channel': (str,),  # noqa: E501
            'track_data': (str,),  # noqa: E501
            'scheduled_at': (datetime,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'msg_id': 'msgId',  # noqa: E501
        'status': 'status',  # noqa: E501
        'status_code': 'statusCode',  # noqa: E501
        'error_code': 'errorCode',  # noqa: E501
        'created_at': 'createdAt',  # noqa: E501
        'in_quiet_hours': 'inQuietHours',  # noqa: E501
        'cost': 'cost',  # noqa: E501
        'to': 'to',  # noqa: E501
        'country_iso': 'countryIso',  # noqa: E501
        '_from': 'from',  # noqa: E501
        'text': 'text',  # noqa: E501
        'parts': 'parts',  # noqa: E501
        'channel': 'channel',  # noqa: E501
        'track_data': 'trackData',  # noqa: E501
        'scheduled_at': 'scheduledAt',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, msg_id, status, status_code, error_code, created_at, in_quiet_hours, cost, to, country_iso, _from, text, parts, channel, *args, **kwargs):  # noqa: E501
        """DataMultichannel - a model

        Args:
            msg_id (str): Unique message identifier needed to track the delivery report
            status (str): Possible status of the message at request time:  * `ACCEPTED` - Message has been accepted for delivery  * `SCHEDULED` - Message has been scheduled at the date time specified  * `REJECTED` - Message was rejected because the number has opted out from receiving messages (no balance deduction, cost zero)  * `NO COVERAGE` - There is no coverage for this destination, no pricing is set (no balance deduction, cost zero)   The final delivery report (DELIVERED, FAILED) will be sent to the URL provided in the `dlrCallbackUrl` parameter or you can query the status at the resource GET `/reports/single/{msgId}` 
            status_code (int): Status code for the delivery report 
            error_code (int, none_type): Status code for the failed delivery report 
            created_at (datetime): Date and time of sending the message
            in_quiet_hours (bool): If the date of send or the schedule date of a message is detected to be in the quiet hours of the destination phone number, this parameter will be set to `true`. This parameter is `false` if no quiet hours detected
            cost (float): The cost of sending a message, in the currency of the account (**eur** or **usd**). 
            to (str): Destination phone number in E.164 format 
            country_iso (str): Two-letter country code in ISO-3166 alpha 2 standard of the destinations. Eg. DE, FR, IT
            _from (str): Originator (sender name) of the message 
            text (str): The text message sent with all the fields/variables replaced (if any).
            parts (int): Message parts. For Viber/Whatsapp/Multichannel this variable is always with value 1
            channel (str):


            track_data (str): Client own UUID (v1-v5) provided to track messages. [optional]  # noqa: E501
            scheduled_at (datetime): Date and time when the Whatsapp message was scheduled. If the date and time of sending or scheduling is detected to be in the quiet hours interval, the API will schedule the sending of the Whatsapp message at the end of the quiet hours. Eg. If quiet hours is defined between 21:30 and 09:30 and the message sending is at 21:55, then the API will schedule the message the next day at 09:31. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.msg_id = msg_id
        self.status = status
        self.status_code = status_code
        self.error_code = error_code
        self.created_at = created_at
        self.in_quiet_hours = in_quiet_hours
        self.cost = cost
        self.to = to
        self.country_iso = country_iso
        self._from = _from
        self.text = text
        self.parts = parts
        self.channel = channel
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, msg_id, status, status_code, error_code, created_at, in_quiet_hours, cost, to, country_iso, _from, text, parts, channel, *args, **kwargs):  # noqa: E501
        """DataMultichannel - a model

        Args:
            msg_id (str): Unique message identifier needed to track the delivery report
            status (str): Possible status of the message at request time:  * `ACCEPTED` - Message has been accepted for delivery  * `SCHEDULED` - Message has been scheduled at the date time specified  * `REJECTED` - Message was rejected because the number has opted out from receiving messages (no balance deduction, cost zero)  * `NO COVERAGE` - There is no coverage for this destination, no pricing is set (no balance deduction, cost zero)   The final delivery report (DELIVERED, FAILED) will be sent to the URL provided in the `dlrCallbackUrl` parameter or you can query the status at the resource GET `/reports/single/{msgId}` 
            status_code (int): Status code for the delivery report 
            error_code (int, none_type): Status code for the failed delivery report 
            created_at (datetime): Date and time of sending the message
            in_quiet_hours (bool): If the date of send or the schedule date of a message is detected to be in the quiet hours of the destination phone number, this parameter will be set to `true`. This parameter is `false` if no quiet hours detected
            cost (float): The cost of sending a message, in the currency of the account (**eur** or **usd**). 
            to (str): Destination phone number in E.164 format 
            country_iso (str): Two-letter country code in ISO-3166 alpha 2 standard of the destinations. Eg. DE, FR, IT
            _from (str): Originator (sender name) of the message 
            text (str): The text message sent with all the fields/variables replaced (if any).
            parts (int): Message parts. For Viber/Whatsapp/Multichannel this variable is always with value 1
            channel (str):


            track_data (str): Client own UUID (v1-v5) provided to track messages. [optional]  # noqa: E501
            scheduled_at (datetime): Date and time when the Whatsapp message was scheduled. If the date and time of sending or scheduling is detected to be in the quiet hours interval, the API will schedule the sending of the Whatsapp message at the end of the quiet hours. Eg. If quiet hours is defined between 21:30 and 09:30 and the message sending is at 21:55, then the API will schedule the message the next day at 09:31. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.msg_id = msg_id
        self.status = status
        self.status_code = status_code
        self.error_code = error_code
        self.created_at = created_at
        self.in_quiet_hours = in_quiet_hours
        self.cost = cost
        self.to = to
        self.country_iso = country_iso
        self._from = _from
        self.text = text
        self.parts = parts
        self.channel = channel
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.quiet_hours import QuietHours
globals()['QuietHours'] = QuietHours
from smscx_client.model.whatsapp import Whatsapp


class TestWhatsapp(unittest.TestCase):
    """Whatsapp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWhatsapp(self):
        """Test Whatsapp"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Whatsapp()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.attachments import Attachments


class TestAttachments(unittest.TestCase):
    """Attachments unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAttachments(self):
        """Test Attachments"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Attachments()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_report_campaign import DataReportCampaign
globals()['DataReportCampaign'] = DataReportCampaign
from smscx_client.model.report_single_response import ReportSingleResponse


class TestReportSingleResponse(unittest.TestCase):
    """ReportSingleResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportSingleResponse(self):
        """Test ReportSingleResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportSingleResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.rental_cost import RentalCost
globals()['RentalCost'] = RentalCost
from smscx_client.model.data_available_numbers_rent import DataAvailableNumbersRent


class TestDataAvailableNumbersRent(unittest.TestCase):
    """DataAvailableNumbersRent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDataAvailableNumbersRent(self):
        """Test DataAvailableNumbersRent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DataAvailableNumbersRent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError



class CallbackEventTypes(ModelSimple):
    """
    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('value',): {
            'DLR_UPDATE': "dlr_update",
            'RECEIVE_SMS': "receive_sms",
            'RECEIVE_VIBER': "receive_viber",
            'RECEIVE_WHATSAPP': "receive_whatsapp",
            'SHORTLINK_HIT': "shortlink_hit",
            'SHORTLINK_HIT_UPDATE': "shortlink_hit_update",
            'ATTACHMENT_HIT': "attachment_hit",
            'ATTACHMENT_HIT_UPDATE': "attachment_hit_update",
            'NEW_OPTOUT': "new_optout",
        },
    }

    validations = {
    }

    additional_properties_type = None

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'value': (str,),
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {}

    read_only_vars = set()

    _composed_schemas = None

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):
        """CallbackEventTypes - a model

        Note that value can be passed either in args or in kwargs, but not in both.

        Args:
            args[0] (str): Event for which the callback request is made., must be one of ["dlr_update", "receive_sms", "receive_viber", "receive_whatsapp", "shortlink_hit", "shortlink_hit_update", "attachment_hit", "attachment_hit_update", "new_optout", ]  # noqa: E501

        Keyword Args:
            value (str): Event for which the callback request is made., must be one of ["dlr_update", "receive_sms", "receive_viber", "receive_whatsapp", "shortlink_hit", "shortlink_hit_update", "attachment_hit", "attachment_hit_update", "new_optout", ]  # noqa: E501
            _check_type (bool): if True, values for parameters in api_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names,.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
        """
        # required up here when default value is not given
        _path_to_item = kwargs.pop('_path_to_item', ())

        if 'value' in kwargs:
            value = kwargs.pop('value')
        elif args:
            args = list(args)
            value = args.pop(0)
        else:
            raise ApiTypeError(
                "value is required, but not passed in args or kwargs and doesn't have default",
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)
        self.value = value
        if kwargs:
            raise ApiTypeError(
                "Invalid named arguments=%s passed to %s. Remove those invalid named arguments." % (
                    kwargs,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, *args, **kwargs):
        """CallbackEventTypes - a model

        Note that value can be passed either in args or in kwargs, but not in both.

        Args:
            args[0] (str): Event for which the callback request is made., must be one of ["dlr_update", "receive_sms", "receive_viber", "receive_whatsapp", "shortlink_hit", "shortlink_hit_update", "attachment_hit", "attachment_hit_update", "new_optout", ]  # noqa: E501

        Keyword Args:
            value (str): Event for which the callback request is made., must be one of ["dlr_update", "receive_sms", "receive_viber", "receive_whatsapp", "shortlink_hit", "shortlink_hit_update", "attachment_hit", "attachment_hit_update", "new_optout", ]  # noqa: E501
            _check_type (bool): if True, values for parameters in api_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names,.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
        """
        # required up here when default value is not given
        _path_to_item = kwargs.pop('_path_to_item', ())

        self = super(ApiModel, cls).__new__(cls)

        if 'value' in kwargs:
            value = kwargs.pop('value')
        elif args:
            args = list(args)
            value = args.pop(0)
        else:
            raise ApiTypeError(
                "value is required, but not passed in args or kwargs and doesn't have default",
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)
        self.value = value
        if kwargs:
            raise ApiTypeError(
                "Invalid named arguments=%s passed to %s. Remove those invalid named arguments." % (
                    kwargs,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        return self



import sys
import unittest

import smscx_client
from smscx_client.model.data_sms import DataSms
from smscx_client.model.info_campaign import InfoCampaign
globals()['DataSms'] = DataSms
globals()['InfoCampaign'] = InfoCampaign
from smscx_client.model.send_sms_campaign_response import SendSmsCampaignResponse


class TestSendSmsCampaignResponse(unittest.TestCase):
    """SendSmsCampaignResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSendSmsCampaignResponse(self):
        """Test SendSmsCampaignResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SendSmsCampaignResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.phone_numbers_by_country import PhoneNumbersByCountry
    globals()['PhoneNumbersByCountry'] = PhoneNumbersByCountry


class InfoMultichannel(ModelNormal):


    allowed_values = {
    }

    validations = {
        ('campaign_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
    }

    @cached_property
    def additional_properties_type():
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'campaign_id': (str,),  # noqa: E501
            'total_phone_numbers': (int,),  # noqa: E501
            'total_valid': (int,),  # noqa: E501
            'total_invalid': (int,),  # noqa: E501
            'total_cost': (float,),  # noqa: E501
            'total_parts': (int,),  # noqa: E501
            'dlr_callback_url': (str, none_type,),  # noqa: E501
            'phone_numbers_by_country': (PhoneNumbersByCountry,),  # noqa: E501
            'scheduled': (bool,),  # noqa: E501
            'total_in_quiet_hours': (int,),  # noqa: E501
            'invalid': ([str],),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'campaign_id': 'campaignId',  # noqa: E501
        'total_phone_numbers': 'totalPhoneNumbers',  # noqa: E501
        'total_valid': 'totalValid',  # noqa: E501
        'total_invalid': 'totalInvalid',  # noqa: E501
        'total_cost': 'totalCost',  # noqa: E501
        'total_parts': 'totalParts',  # noqa: E501
        'dlr_callback_url': 'dlrCallbackUrl',  # noqa: E501
        'phone_numbers_by_country': 'phoneNumbersByCountry',  # noqa: E501
        'scheduled': 'scheduled',  # noqa: E501
        'total_in_quiet_hours': 'totalInQuietHours',  # noqa: E501
        'invalid': 'invalid',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, campaign_id, total_phone_numbers, total_valid, total_invalid, total_cost, total_parts, dlr_callback_url, phone_numbers_by_country, scheduled, *args, **kwargs):  # noqa: E501
        """InfoMultichannel - a model

        Args:
            campaign_id (str): Unique identifier of the campaign
            total_phone_numbers (int): Total phone numbers submitted for processing
            total_valid (int): Total valid phone numbers after validation
            total_invalid (int): Total invalid phone numbers after validation
            total_cost (float): Total cost of sending the message
            total_parts (int): Total message parts
            dlr_callback_url (str, none_type): Callback URL for receiving the delivery report
            phone_numbers_by_country (PhoneNumbersByCountry):
            scheduled (bool): Confirmation that the message/campaign was scheduled at a later date


            total_in_quiet_hours (int): Total phone numbers that were detected to be inside the interval of quiet hours. [optional]  # noqa: E501
            invalid ([str]): An array with numbers that were detected to be invalid. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.campaign_id = campaign_id
        self.total_phone_numbers = total_phone_numbers
        self.total_valid = total_valid
        self.total_invalid = total_invalid
        self.total_cost = total_cost
        self.total_parts = total_parts
        self.dlr_callback_url = dlr_callback_url
        self.phone_numbers_by_country = phone_numbers_by_country
        self.scheduled = scheduled
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, campaign_id, total_phone_numbers, total_valid, total_invalid, total_cost, total_parts, dlr_callback_url, phone_numbers_by_country, scheduled, *args, **kwargs):  # noqa: E501
        """InfoMultichannel - a model

        Args:
            campaign_id (str): Unique identifier of the campaign
            total_phone_numbers (int): Total phone numbers submitted for processing
            total_valid (int): Total valid phone numbers after validation
            total_invalid (int): Total invalid phone numbers after validation
            total_cost (float): Total cost of sending the message
            total_parts (int): Total message parts
            dlr_callback_url (str, none_type): Callback URL for receiving the delivery report
            phone_numbers_by_country (PhoneNumbersByCountry):
            scheduled (bool): Confirmation that the message/campaign was scheduled at a later date


            total_in_quiet_hours (int): Total phone numbers that were detected to be inside the interval of quiet hours. [optional]  # noqa: E501
            invalid ([str]): An array with numbers that were detected to be invalid. [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.campaign_id = campaign_id
        self.total_phone_numbers = total_phone_numbers
        self.total_valid = total_valid
        self.total_invalid = total_invalid
        self.total_cost = total_cost
        self.total_parts = total_parts
        self.dlr_callback_url = dlr_callback_url
        self.phone_numbers_by_country = phone_numbers_by_country
        self.scheduled = scheduled
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.info_originator import InfoOriginator
globals()['InfoOriginator'] = InfoOriginator
from smscx_client.model.originator_new_response import OriginatorNewResponse


class TestOriginatorNewResponse(unittest.TestCase):
    """OriginatorNewResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOriginatorNewResponse(self):
        """Test OriginatorNewResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OriginatorNewResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
